@@ -664,20 +664,11 @@ activate_action_properties (GtkAction *action,
 void
 activate_action_close (GtkAction *action, 
 		       gpointer   data)
-{
-	window_archive_close ((FRWindow*) data);
-}
-
-
-void
-activate_action_quit (GtkAction *action, 
-		      gpointer   data)
 {
 	FRWindow *window = data;
 	window_close (window);
 }
 
-
 void
 activate_action_add_files (GtkAction *action, 
 			   gpointer   data)
