@@ -26,12 +26,12 @@
 #include <time.h>
 
 #include <glib.h>
-#include <gnome.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
 
 #include "file-data.h"
 #include "file-utils.h"
+#include "glib-utils.h"
 #include "fr-command.h"
 #include "fr-command-rpm.h"
 
@@ -64,7 +64,21 @@ mktime_from_string (char *month,
 			}
 	}
 	tm.tm_mday = atoi (mday);
-	tm.tm_year = atoi (year) - 1900;
+	if (strchr (year, ':') != NULL) {
+		char **fields = g_strsplit (year, ":", 2);
+        	if (n_fields (fields) == 2) {
+	        	time_t      now;
+        		struct tm  *now_tm;
+
+	  		tm.tm_hour = atoi (fields[0]) - 1;
+	  		tm.tm_min = atoi (fields[1]);
+	  
+	  		now = time(NULL);
+	  		now_tm = localtime (&now);
+	  		tm.tm_year = now_tm->tm_year;
+        	}
+	} else
+		tm.tm_year = atoi (year) - 1900;
 
 	return mktime (&tm);
 }
@@ -86,14 +100,22 @@ list__process_line (char     *line,
 
 	fdata = file_data_new ();
 
+#ifdef __sun
+	fields = split_line (line, 9);
+	fdata->size = g_ascii_strtoull (fields[4], NULL, 10);
+	fdata->modified = mktime_from_string (fields[5], fields[6], fields[8]);
+	g_strfreev (fields);
+
+	name_field = get_last_field (line, 10);
+#else
 	fields = split_line (line, 8);
-	fdata->size = atol (fields[4]);
+	fdata->size = g_ascii_strtoull (fields[4], NULL, 10);
 	fdata->modified = mktime_from_string (fields[5], fields[6], fields[7]);
 	g_strfreev (fields);
 
-	/* Full path */
-
 	name_field = get_last_field (line, 9);
+#endif /* __sun */
+
 	fields = g_strsplit (name_field, " -> ", 2);
 
 	if (fields[1] == NULL) {
@@ -115,7 +137,6 @@ list__process_line (char     *line,
 
 	fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 	fdata->path = remove_level_from_path (fdata->full_path);
-	fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
 
 	if (*fdata->name == 0)
 		file_data_free (fdata);
@@ -125,7 +146,8 @@ list__process_line (char     *line,
 
 
 static void
-fr_command_rpm_list (FRCommand *comm)
+fr_command_rpm_list (FRCommand  *comm,
+		     const char *password)
 {
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
 				      list__process_line,
@@ -133,7 +155,7 @@ fr_command_rpm_list (FRCommand *comm)
 
 	fr_process_begin_command (comm->process, "rpm2cpio");
 	fr_process_add_arg (comm->process, comm->e_filename);
-	fr_process_add_arg (comm->process, "| cpio --list --force-local --verbose");
+	fr_process_add_arg (comm->process, "| cpio -itv");
 	fr_process_end_command (comm->process);
 	fr_process_start (comm->process);
 }
@@ -154,7 +176,7 @@ fr_command_rpm_extract (FRCommand  *comm,
 	if (dest_dir != NULL)
                 fr_process_set_working_dir (comm->process, dest_dir);
 	fr_process_add_arg (comm->process, comm->e_filename);
-	fr_process_add_arg (comm->process, "| cpio --extract --force-local --unconditional --make-directories");
+	fr_process_add_arg (comm->process, "| cpio -idu");
 	for (scan = file_list; scan; scan = scan->next) {
 		char *filename = (char*) scan->data;
 		fr_process_add_arg (comm->process, filename);
@@ -183,6 +205,8 @@ fr_command_rpm_class_init (FRCommandRpmClass *class)
 static void 
 fr_command_rpm_init (FRCommand *comm)
 {
+	comm->file_type = FR_FILE_TYPE_RPM;
+
 	comm->propCanModify                = FALSE;
 	comm->propAddCanUpdate             = FALSE;
 	comm->propAddCanReplace            = FALSE;
